.. module:: hubugs.utils

Utilities
=========

.. note::

   The documentation in this section is aimed at people wishing to contribute
   to :mod:`hubugs`, and can be skipped if you are simply using the tool from
   the command line.

.. autofunction:: setup_environment

Convenience functions
---------------------

.. autofunction:: get_editor
.. autofunction:: pager

Git/GitHub support
------------------

.. autofunction:: get_github_api
.. autofunction:: get_git_config_val
.. autofunction:: set_git_config_val
.. autofunction:: get_repo
.. autofunction:: sync_labels
